@@ -34,17 +34,15 @@
 #' @keywords manip
 #'
 #' @examples
-#' # load weight-length data
-#' data(ChinookArg)
-#' # add log length and weight data
+#' # add log length and weight data to ChinookArg data
 #' ChinookArg$logtl <- log(ChinookArg$tl)
 #' ChinookArg$logwt <- log(ChinookArg$w)
 #' # fit model to assess equality of slopes
 #' lm1 <- lm(logwt~logtl*loc,data=ChinookArg)
 #' anova(lm1)
 #'
-#' # set par so that the plots will look decent
-#' par(mar=c(3.5,3.5,1,1),mgp=c(1.8,0.4,0),tcl=-0.2)
+#' # set graphing parameters so that the plots will look decent
+#' op <- par(mar=c(3.5,3.5,1,1),mgp=c(1.8,0.4,0),tcl=-0.2)
 #' # show predicted weights (w/ CI) at the default quantile lengths for each year
 #' lwCompPreds(lm1,xlab="Location")
 #' # show predicted weights (w/ CI) at the quartile lengths for each year
@@ -82,10 +80,15 @@
 #'   lwCompPreds(lm3)   
 #' }
 #' 
+#' ## return graphing parameters to original state
+#' par(op)
+#' 
 #' @export lwCompPreds
-lwCompPreds <- function(object,lens=NULL,qlens=c(0.05,0.25,0.5,0.75,0.95),qlens.dec=1,base=exp(1),
-                        interval=c("confidence","prediction","both"),center.value=0,
-                        lwd=1,connect.preds=TRUE,show.preds=FALSE,col.connect="gray50",
+lwCompPreds <- function(object,lens=NULL,qlens=c(0.05,0.25,0.5,0.75,0.95),
+                        qlens.dec=1,base=exp(1),
+                        interval=c("confidence","prediction","both"),
+                        center.value=0,lwd=1,connect.preds=TRUE,
+                        show.preds=FALSE,col.connect="gray50",
                         ylim=NULL,main.pre="Length==",cex.main=0.8,
                         xlab="Groups",ylab="Predicted Weight",yaxs="r",
                         rows=round(sqrt(num)),cols=ceiling(sqrt(num))) {
@@ -121,7 +124,7 @@ lwCompPreds <- function(object,lens=NULL,qlens=c(0.05,0.25,0.5,0.75,0.95),qlens.
   # number of plots to construct
   num <- length(lens)
   # reset par so as to make nice plots
-  opar <- graphics::par(mfrow=c(rows,cols))
+  withr::local_par(list(mfrow=c(rows,cols)))
   # cycle through the lengths
   for (i in seq_along(lens)) {
     # find results for each length
@@ -130,7 +133,6 @@ lwCompPreds <- function(object,lens=NULL,qlens=c(0.05,0.25,0.5,0.75,0.95),qlens.
     iPlotLWPred(res,grps,ylim,xlab,ylab,paste0(main.pre,lens[i]),
                 cex.main,lwd,connect.preds,col.connect,interval,show.preds,yaxs)
   }
-  graphics::par(opar)
 } # nocov end
 
 
