@@ -78,16 +78,16 @@
 #' ## different subsets of fish
 #' # ... without any sub-stock fish
 #' brks <- psdVal("Yellow Perch")
-#' tmp <- Subset(df,mm>brks["stock"])
+#' tmp <- filterD(df,mm>brks["stock"])
 #' psdPlot(~mm,data=tmp,species="Yellow perch",w=10)
 #' # ... without any sub-stock or stock fish
-#' tmp <- Subset(df,mm>brks["quality"])
+#' tmp <- filterD(df,mm>brks["quality"])
 #' psdPlot(~mm,data=tmp,species="Yellow perch",w=10)
 #' # ... with only sub-stock, stock, and quality fish ... only PSD-Q
-#' tmp <- Subset(df,mm<brks["preferred"])
+#' tmp <- filterD(df,mm<brks["preferred"])
 #' psdPlot(~mm,data=tmp,species="Yellow perch",w=10)
 #' # ... with only sub-stock fish (don't run ... setup to give an error)
-#' tmp <- Subset(df,mm<brks["stock"])
+#' tmp <- filterD(df,mm<brks["stock"])
 #' \dontrun{ psdPlot(~mm,data=tmp,species="Yellow perch",w=10) }
 #' par(op)
 #'
@@ -149,7 +149,7 @@ iAddPSDLeg <- function(formula,data,cl,brks,species,units,psd.pos,psd.cex) { # n
   psds <- psds[psds[,"Estimate"]>0,,drop=FALSE]
   # get two sample sizes
   n <- nrow(data)
-  n.stock <- nrow(Subset(data,data[,cl]>brks["stock"]))
+  n.stock <- nrow(filterD(data,data[,cl]>brks["stock"]))
   # put it all together
   psdleg <- paste(c("n","n[stock]",rownames(psds)),"=",
                   formatC(c(n,n.stock,psds[,"Estimate"]),
